==> Meta-0.05.tar.gz: Meta-0.05/Meta/Tests/regression/soap.pl <==
#!/usr/bin/env perl

use strict qw(vars refs subs);
use Meta::Utils::System qw();
use Meta::Utils::Opts::Opts qw();
use Meta::Baseline::Test qw();
use Meta::Comm::Soap::Server qw();
use Meta::Comm::Soap::Client qw();
use Meta::Utils::Output qw();
use Meta::Info::Author qw();

my($opts)=Meta::Utils::Opts::Opts->new();
$opts->set_standard();
$opts->set_free_allo(0);
$opts->analyze(\@ARGV);

Meta::Baseline::Test::redirect_on();

#if(CORE::fork()) {#server side
#	Meta::Utils::Output::print("in server side\n");
#	my($server)=Meta::Comm::Soap::Server->new();
#	$server->dispatch_to("Meta::Info::Author");
#	$server->handle();
#} else {#client side
#	Meta::Utils::Output::print("in client side\n");
#	CORE::sleep(2);#wait for server to be up
#	my($client)=Meta::Comm::Soap::Client->new();
#	$client->uri("uri");
#	#$client->proxy("tcp://localhost:10001");
#	my($a)=Meta::Info::Author->SOAP::new();
#	#$a->set_firstname("mark");
#	#my($name)=$a->get_firstname();
#	#Meta::Utils::Output::print("name is [".$name."]\n");
#}
my($scod)=1;

Meta::Baseline::Test::redirect_off();

Meta::Utils::System::exit($scod);

__END__

=head1 NAME

soap.pl - test client/server communication.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: soap.pl
	PROJECT: meta
	VERSION: 0.10

=head1 SYNOPSIS

	soap.pl

=head1 DESCRIPTION

This test creates a client and server classes and tests communication
between them.

=head1 OPTIONS

=over 4

=item B<help> (type: bool, default: 0)

display help message

=item B<pod> (type: bool, default: 0)

display pod options snipplet

=item B<man> (type: bool, default: 0)

display manual page

=item B<quit> (type: bool, default: 0)

quit without doing anything

=item B<gtk> (type: bool, default: 0)

run a gtk ui to get the parameters

=item B<license> (type: bool, default: 0)

show license and exit

=item B<copyright> (type: bool, default: 0)

show copyright and exit

=item B<history> (type: bool, default: 0)

show history and exit

=back

no free arguments are allowed

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV stuff
	0.01 MV license issues
	0.02 MV md5 project
	0.03 MV database
	0.04 MV perl module versions in files
	0.05 MV thumbnail user interface
	0.06 MV more thumbnail issues
	0.07 MV website construction
	0.08 MV improve the movie db xml
	0.09 MV web site automation
	0.10 MV SEE ALSO section fix

=head1 SEE ALSO

Meta::Baseline::Test(3), Meta::Comm::Soap::Client(3), Meta::Comm::Soap::Server(3), Meta::Info::Author(3), Meta::Utils::Opts::Opts(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)

=head1 TODO

Nothing.

==> Meta-0.06.tar.gz: Meta-0.06/Meta/Tests/regression/soap.pl <==
#!/usr/bin/env perl

use strict qw(vars refs subs);
use Meta::Utils::System qw();
use Meta::Utils::Opts::Opts qw();
use Meta::Baseline::Test qw();
use Meta::Comm::Soap::Server qw();
use Meta::Comm::Soap::Client qw();
use Meta::Utils::Output qw();
use Meta::Info::Author qw();

my($opts)=Meta::Utils::Opts::Opts->new();
$opts->set_standard();
$opts->set_free_allo(0);
$opts->analyze(\@ARGV);

Meta::Baseline::Test::redirect_on();

#if(CORE::fork()) {#server side
#	Meta::Utils::Output::print("in server side\n");
#	my($server)=Meta::Comm::Soap::Server->new();
#	$server->dispatch_to("Meta::Info::Author");
#	$server->handle();
#} else {#client side
#	Meta::Utils::Output::print("in client side\n");
#	CORE::sleep(2);#wait for server to be up
#	my($client)=Meta::Comm::Soap::Client->new();
#	$client->uri("uri");
#	#$client->proxy("tcp://localhost:10001");
#	my($a)=Meta::Info::Author->SOAP::new();
#	#$a->set_firstname("mark");
#	#my($name)=$a->get_firstname();
#	#Meta::Utils::Output::print("name is [".$name."]\n");
#}
my($scod)=1;

Meta::Baseline::Test::redirect_off();

Meta::Utils::System::exit($scod);

__END__

=head1 NAME

soap.pl - test client/server communication.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: soap.pl
	PROJECT: meta
	VERSION: 0.12

=head1 SYNOPSIS

	soap.pl

=head1 DESCRIPTION

This test creates a client and server classes and tests communication
between them.

=head1 OPTIONS

=over 4

=item B<help> (type: bool, default: 0)

display help message

=item B<pod> (type: bool, default: 0)

display pod options snipplet

=item B<man> (type: bool, default: 0)

display manual page

=item B<quit> (type: bool, default: 0)

quit without doing anything

=item B<gtk> (type: bool, default: 0)

run a gtk ui to get the parameters

=item B<license> (type: bool, default: 0)

show license and exit

=item B<copyright> (type: bool, default: 0)

show copyright and exit

=item B<description> (type: bool, default: 0)

show description and exit

=item B<history> (type: bool, default: 0)

show history and exit

=back

no free arguments are allowed

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV stuff
	0.01 MV license issues
	0.02 MV md5 project
	0.03 MV database
	0.04 MV perl module versions in files
	0.05 MV thumbnail user interface
	0.06 MV more thumbnail issues
	0.07 MV website construction
	0.08 MV improve the movie db xml
	0.09 MV web site automation
	0.10 MV SEE ALSO section fix
	0.11 MV move tests to modules
	0.12 MV bring movie data

=head1 SEE ALSO

Meta::Baseline::Test(3), Meta::Comm::Soap::Client(3), Meta::Comm::Soap::Server(3), Meta::Info::Author(3), Meta::Utils::Opts::Opts(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)

=head1 TODO

Nothing.
